@@ -92,12 +92,4 @@ def read(sock, get=False, data=False):
             break
 
     if 'get':
-        return message
-    
-    
-s = connect('cgate.pro')
-login(s, 'khajiit', '+=stalker-soft=+')
-from CGPCLI.Commands import noop, get_account_info
-print(get_account_info(s, '*'))
-print(noop(s))
-disconnect(s)        
\ No newline at end of file
+        return message
\ No newline at end of file
